PyXMake Developer Guide: PyXMake.VTL.stm_make.bundle_pycodac Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.bundle_pycodac Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.bundle_pycodac:

## Public Attributes
| install_path = os.getenv("plugin_central_dir",os.path.join(Utility.AsDrive("c"),"simulia","cae","plugins","2019"))
Public Attributes inherited from PyXMake.VTL.stm_make.pyx_bundle
int | verbose = 0
str | source_path = ''
str | output_file_path = ''
| scratch_path = os.getcwd()
str | install_path = "$Desktop"
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Protected Member Functions
| _create_command (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make.pyx_bundle
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _perform_post_actions (self)

## Static Protected Attributes
str | _BUNDLE_NAME = 'STMLab'
str | _INPUT_FILES = "*.*"
Static Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_bundle
str | _BUNDLE_NAME = ''
str | _INPUT_FILES = ""

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make.pyx_bundle
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make.pyx_bundle
str | description = "Compile a stand-alone installer using NSIS."
list | user_options
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Create an installer for STMLab using PyCODAC.

Definition at line 248 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.bundle_pycodac._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 256 of file stm_make.py.

## Member Data Documentation

## ◆ _BUNDLE_NAME

str PyXMake.VTL.stm_make.bundle_pycodac._BUNDLE_NAME = 'STMLab'
| staticprotected

Definition at line 253 of file stm_make.py.

## ◆ _INPUT_FILES

str PyXMake.VTL.stm_make.bundle_pycodac._INPUT_FILES = "*.*"
| staticprotected

Definition at line 254 of file stm_make.py.

## ◆ install_path

PyXMake.VTL.stm_make.bundle_pycodac.install_path = os.getenv("plugin_central_dir",os.path.join(Utility.AsDrive("c"),"simulia","cae","plugins","2019"))

Definition at line 261 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py